<?php

/**
 * @file
 * Contains tokens for paragraphs_summary_token module.
 */

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\ContentEntityTypeInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Implements hook_token_info().
 */
function paragraphs_summary_token_token_info() {
  $info = [];

  $entityTypeDefininitions = \Drupal::entityTypeManager()->getDefinitions();

  /** @var \Drupal\Core\Entity\ContentEntityTypeInterface[] $contentEntityTypes */
  $contentEntityTypes = [];
  foreach ($entityTypeDefininitions as $definition) {
    if ($definition instanceof ContentEntityTypeInterface) {
      $contentEntityTypes[] = $definition;
    }
  }

  foreach ($contentEntityTypes as $contentEntityType) {
    $info[$contentEntityType->id()]['paragraphs_summary'] = [
      'name' => 'Paragraphs summary',
      'description' => new TranslatableMarkup('Builds the paragraphs summary.'),
    ];
  }

  return $info;
}

/**
 * Implements hook_tokens().
 */
function paragraphs_summary_token_tokens($type, $tokens, array $data = [], array $options = []) {
  $return = [];

  if ($type === 'entity' && !empty($data['entity']) && $data['entity'] instanceof ContentEntityInterface) {
    foreach ($tokens as $name => $original) {
      if ($name === 'paragraphs_summary') {
        $return[$original] = \Drupal::service('paragraphs_summary_token.summary_builder')->build($data['entity'], 300);
      }
    }
  }

  return $return;
}
